# 更新日志
## kaa
### v2025.3.9
脚本：
* [修复] 修复部分情况下工作分配偶像选择页面报错（#a35e6c3）
* [修复] 修复培育中强化技能卡时有几率卡在确认按钮上（#221721a）
* [新增] 支持指定培育中行动优先级（#fc8c456）
* [新增] 支持处理培育结束时的未读交流（#452ba67）
* [新增] 培育中支持优先选择 SP 课程（#ee3808c）
* [新增] 培育中文化课（授業）行动支持处理自习事件（#47287fd）

界面：
* [新增] UI 上实时展示设备画面（#72a1a17）

框架：
* [修复] 修复调试模式下内存中截图数据不会释放的问题（#bead31a）
* [修复] 修复启动模拟器前不会自动检测是否已启动的问题（#71d75b7）
* [修复] 修复若软件处于中文目录，读取图片资源失败的问题（#a8aee32）
* [新增] 降低双击默认速度（#e63ad2d）
* [新增] 支持启动 kaa 前自动启动模拟器（#8ee51ba）
* [重构] 移动 grayscaled 和 unify_image 函数的位置（#500e11d）
* [重构] 移动 util 模块位置（#0d3e5de）
* [重构] 移除原有 kotonebot.run 模块中函数，改用 Kotonebot 类（#508d81c）

开发工具：
* [修复] 修复写出 dumps 文件时的编码问题（#d5c64df）
* [新增] 优化 DumpViewer 调用堆栈部分与时间部分的显示（#41d4c4c）
* [新增] ImageAnnotation 新增 description 字段（#425057d）
* [新增] DumpViewer 新增滚动锁定按钮（#79927a7）
* [新增] DumpViewer 两次结果之间新增时间差显示（#e3583f2）
* [重构] 将调试 WS 消息体提取为 pydantic Model（#abf7fbc）

其他：
* [其他] R.py 中的 HintBox 类型的注释也加入裁剪后图片的展示（#7907e44）

### v2025.3.1.0
脚本：
* [新增] 新增支持指定回忆编成编号（#6482962）
* [新增] 优化培育与日常流程，修复一些 bug（#145f97f）
* [新增] 支持处理外出行动 & 优化部分流程（#03fdfaa）
* [新增] 新增支持处理技能卡强化选择事件（#133f084）
* [新增] 培育中支持识别睡意 T 卡（眠気）（#5a68500）
* [修复] 修复课程中无法处理当前回合无剩余手牌的情况（#bfb574c）
* [修复] 修复课程中遇到四/五张手牌时会卡住的问题（#ae22253）
* [修复] 修复某些情况下会卡在培育开始第二步（#73dc4d8）
* [修复] 修复某些情况下会卡在工作分配偶像选择页面（#2ff655f）

界面：
* [新增] UI 上新增更新日志 Tab（#07be7b3）
* [新增] 新增一键上传日志报告功能（#62d5805）

框架：
* [新增] device.click() 方法新增支持传入 tuple[int, int]（#f146038）
* [新增] adb_raw 截图方法加入超时自动重试（#08f382c）
* [新增] 为 device.click() 方法添加可视调试信息（#be37164）
* [新增] 为 adb_raw 截图方式的截图线程加入自动重试（#9b25098）
* [修复] 修复了 device.click() 调试信息在没有截图数据时会报错（#f0a3baa）
* [修复] 修复写入调试数据前不会自动清空上次数据的问题（#80e04ee）

其他：
* [新增] ImageAnntation 页面与 Python 代码引入 HintPoint 支持（#949e28d）
* [修复] 修复某些情况下会卡在领取任务奖励处（#f80660e）
* [单测] 移除无用单元测试（#54f9b03）

### v2025.2.23.0
修复：
* 返回首页时无法处理弹出某些弹窗
* 培育中，某些情况下会卡在饮料领取弹窗
* 培育中，某些情况下会在饮料领取时报错

新增：
* 支持处理游戏本体更新弹窗
* 培育中，支持处理技能卡移除事件
* 培育结束时，支持处理“偶像强化月”活动的新纪录弹窗
* UI 标题上新增版本号显示

### v2025.2.20.1
修复：
* ADB 设备连接失败的问题

### v2025.2.20.0
初始版本。